@@ -38,9 +38,5 @@ class ConcreteData:
             train, val = train_test_split(table, test_size=self.val_split, shuffle=True)
         else:
             train, val = table, []
-        self.data = {
-            'train': train,
-            'val': val,
-            'all': np.concatenate((train, val))
-        }
+        self.data = {'train': train, 'val': val}
 
